@@ -31,7 +31,6 @@ if(length(y) > length(x)) {
 
 # normal plot -- not a step function
 else {
-	message('plotting lines...')
 	
 	# if we have an upper and lower bound defined, plot them
 	if(!missing(upper) & !missing(lower)) {
@@ -96,31 +95,34 @@ else {
 		})
 	}
 
+	
+	# TODO: might be interesting to plot group-wise CFs using same colors as lines / polygons
   # annotate with contributing fraction
   if(! is.null(cf)) {
-    # test for groups: CF labeling with grouped data isn't yet defined
-    if(!missing(groups))
-      warning('contributing fraction annotation with grouped data is not yet supported', call.=FALSE)
-    else {
-      # get contributing fraction values for this panel
-      cf.i <- cf[subscripts]
-      
-      # make a function for linear interpolation of CF values based on depth
-      cf.approx.fun <- approxfun(y, cf.i, method='linear')
-      
-      # generate annotated depths: 5 cm to 95th percentile of max depth
-      y.q95 <- quantile(y, probs=c(0.95), na.rm=TRUE)
-      a.seq <- seq(from=5, to=y.q95, by=20)
-      
-      # interpolate CF at annotated depths
-      a.CF <- cf.approx.fun(a.seq)
-      a.text <- paste(round(a.CF * 100), '%')
-      
-      # add to right-hand side of the panel
-      unit <- gpar <- NULL
-      grid.text(a.text, x=unit(0.99, 'npc'), y=unit(a.seq, 'native'), just='right', gp=gpar(font=3, cex=0.8))  
-      }
-    }
+    
+  	# if plotting with grouped data, inform the user we are computing the mean CF / slice
+  	if(!missing(groups))
+  		warning('depth-wise mean contributing fraction values are printed', call.=FALSE)
+
+  	# aggregate group-wise to get a single CF / depth-slice
+  	cf.i.agg <- tapply(cf[subscripts], y, FUN=mean, na.rm=TRUE)
+  	
+    # make a function for linear interpolation of CF values based on depth
+  	# note that we are using unique(y) as grouped data will repeat y n-group times
+    cf.approx.fun <- approxfun(unique(y), cf.i.agg, method='linear')
+    
+    # generate annotated depths: 5 cm to 95th percentile of max depth
+    y.q95 <- quantile(y, probs=c(0.95), na.rm=TRUE)
+    a.seq <- seq(from=5, to=y.q95, by=20)
+    
+    # interpolate CF at annotated depths
+    a.CF <- cf.approx.fun(a.seq)
+    a.text <- paste(round(a.CF * 100), '%')
+    
+    # add to right-hand side of the panel
+    unit <- gpar <- NULL
+    grid.text(a.text, x=unit(0.99, 'npc'), y=unit(a.seq, 'native'), just='right', gp=gpar(font=3, cex=0.8))  
+  }
 
 }
 
